@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ruby-extra-highlight" "0.0.1"
+(define-package "ruby-extra-highlight" "20250103.1518"
   "Highlight Ruby parameters."
   ()
   :url "https://github.com/Lindydancer/ruby-extra-highlight"
